package com.ruoyi.project.system.mapper;

import java.util.List;
import com.ruoyi.project.system.domain.ZhCompanyInfo;

/**
 * 【请填写功能名称】Mapper接口
 * 
 * @author zhu
 * @date 2023-12-26
 */
public interface ZhCompanyInfoMapper 
{
    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public ZhCompanyInfo selectZhCompanyInfoById(Long id);

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param zhCompanyInfo 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<ZhCompanyInfo> selectZhCompanyInfoList(ZhCompanyInfo zhCompanyInfo);

    /**
     * 新增【请填写功能名称】
     * 
     * @param zhCompanyInfo 【请填写功能名称】
     * @return 结果
     */
    public int insertZhCompanyInfo(ZhCompanyInfo zhCompanyInfo);

    /**
     * 修改【请填写功能名称】
     * 
     * @param zhCompanyInfo 【请填写功能名称】
     * @return 结果
     */
    public int updateZhCompanyInfo(ZhCompanyInfo zhCompanyInfo);

    /**
     * 删除【请填写功能名称】
     * 
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteZhCompanyInfoById(Long id);

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteZhCompanyInfoByIds(Long[] ids);
}
